# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/pubsub_v1/proto/pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/pubsub_v1/proto/pubsub.proto",
    package="google.pubsub.v1",
    syntax="proto3",
    serialized_options=b"\n\024com.google.pubsub.v1B\013PubsubProtoP\001Z6google.golang.org/genproto/googleapis/pubsub/v1;pubsub\370\001\001\252\002\026Google.Cloud.PubSub.V1\312\002\026Google\\Cloud\\PubSub\\V1\352\002\031Google::Cloud::PubSub::V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n)google/cloud/pubsub_v1/proto/pubsub.proto\x12\x10google.pubsub.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto";\n\x14MessageStoragePolicy\x12#\n\x1b\x61llowed_persistence_regions\x18\x01 \x03(\t"\xb2\x02\n\x05Topic\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x33\n\x06labels\x18\x02 \x03(\x0b\x32#.google.pubsub.v1.Topic.LabelsEntry\x12\x46\n\x16message_storage_policy\x18\x03 \x01(\x0b\x32&.google.pubsub.v1.MessageStoragePolicy\x12\x14\n\x0ckms_key_name\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:T\xea\x41Q\n\x1bpubsub.googleapis.com/Topic\x12!projects/{project}/topics/{topic}\x12\x0f_deleted-topic_"\xf1\x01\n\rPubsubMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x43\n\nattributes\x18\x02 \x03(\x0b\x32/.google.pubsub.v1.PubsubMessage.AttributesEntry\x12\x12\n\nmessage_id\x18\x03 \x01(\t\x12\x30\n\x0cpublish_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cordering_key\x18\x05 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"E\n\x0fGetTopicRequest\x12\x32\n\x05topic\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic"w\n\x12UpdateTopicRequest\x12+\n\x05topic\x18\x01 \x01(\x0b\x32\x17.google.pubsub.v1.TopicB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"|\n\x0ePublishRequest\x12\x32\n\x05topic\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic\x12\x36\n\x08messages\x18\x02 \x03(\x0b\x32\x1f.google.pubsub.v1.PubsubMessageB\x03\xe0\x41\x02"&\n\x0fPublishResponse\x12\x13\n\x0bmessage_ids\x18\x01 \x03(\t"\x80\x01\n\x11ListTopicsRequest\x12\x44\n\x07project\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"V\n\x12ListTopicsResponse\x12\'\n\x06topics\x18\x01 \x03(\x0b\x32\x17.google.pubsub.v1.Topic\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"z\n\x1dListTopicSubscriptionsRequest\x12\x32\n\x05topic\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"y\n\x1eListTopicSubscriptionsResponse\x12>\n\rsubscriptions\x18\x01 \x03(\tB\'\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"v\n\x19ListTopicSnapshotsRequest\x12\x32\n\x05topic\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"H\n\x1aListTopicSnapshotsResponse\x12\x11\n\tsnapshots\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"H\n\x12\x44\x65leteTopicRequest\x12\x32\n\x05topic\x18\x01 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic"]\n\x19\x44\x65tachSubscriptionRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription"\x1c\n\x1a\x44\x65tachSubscriptionResponse"\xc0\x05\n\x0cSubscription\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x32\n\x05topic\x18\x02 \x01(\tB#\xe0\x41\x02\xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic\x12\x31\n\x0bpush_config\x18\x04 \x01(\x0b\x32\x1c.google.pubsub.v1.PushConfig\x12\x1c\n\x14\x61\x63k_deadline_seconds\x18\x05 \x01(\x05\x12\x1d\n\x15retain_acked_messages\x18\x07 \x01(\x08\x12=\n\x1amessage_retention_duration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x06labels\x18\t \x03(\x0b\x32*.google.pubsub.v1.Subscription.LabelsEntry\x12\x1f\n\x17\x65nable_message_ordering\x18\n \x01(\x08\x12=\n\x11\x65xpiration_policy\x18\x0b \x01(\x0b\x32".google.pubsub.v1.ExpirationPolicy\x12\x0e\n\x06\x66ilter\x18\x0c \x01(\t\x12>\n\x12\x64\x65\x61\x64_letter_policy\x18\r \x01(\x0b\x32".google.pubsub.v1.DeadLetterPolicy\x12\x33\n\x0cretry_policy\x18\x0e \x01(\x0b\x32\x1d.google.pubsub.v1.RetryPolicy\x12\x10\n\x08\x64\x65tached\x18\x0f \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:X\xea\x41U\n"pubsub.googleapis.com/Subscription\x12/projects/{project}/subscriptions/{subscription}"u\n\x0bRetryPolicy\x12\x32\n\x0fminimum_backoff\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0fmaximum_backoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration"L\n\x10\x44\x65\x61\x64LetterPolicy\x12\x19\n\x11\x64\x65\x61\x64_letter_topic\x18\x01 \x01(\t\x12\x1d\n\x15max_delivery_attempts\x18\x02 \x01(\x05":\n\x10\x45xpirationPolicy\x12&\n\x03ttl\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration"\xad\x02\n\nPushConfig\x12\x15\n\rpush_endpoint\x18\x01 \x01(\t\x12@\n\nattributes\x18\x02 \x03(\x0b\x32,.google.pubsub.v1.PushConfig.AttributesEntry\x12<\n\noidc_token\x18\x03 \x01(\x0b\x32&.google.pubsub.v1.PushConfig.OidcTokenH\x00\x1a<\n\tOidcToken\x12\x1d\n\x15service_account_email\x18\x01 \x01(\t\x12\x10\n\x08\x61udience\x18\x02 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x17\n\x15\x61uthentication_method"m\n\x0fReceivedMessage\x12\x0e\n\x06\x61\x63k_id\x18\x01 \x01(\t\x12\x30\n\x07message\x18\x02 \x01(\x0b\x32\x1f.google.pubsub.v1.PubsubMessage\x12\x18\n\x10\x64\x65livery_attempt\x18\x03 \x01(\x05"Z\n\x16GetSubscriptionRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription"\x8c\x01\n\x19UpdateSubscriptionRequest\x12\x39\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1e.google.pubsub.v1.SubscriptionB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"\x87\x01\n\x18ListSubscriptionsRequest\x12\x44\n\x07project\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"k\n\x19ListSubscriptionsResponse\x12\x35\n\rsubscriptions\x18\x01 \x03(\x0b\x32\x1e.google.pubsub.v1.Subscription\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"]\n\x19\x44\x65leteSubscriptionRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription"\x93\x01\n\x17ModifyPushConfigRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x36\n\x0bpush_config\x18\x02 \x01(\x0b\x32\x1c.google.pubsub.v1.PushConfigB\x03\xe0\x41\x02"\x8d\x01\n\x0bPullRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12!\n\x12return_immediately\x18\x02 \x01(\x08\x42\x05\x18\x01\xe0\x41\x01\x12\x19\n\x0cmax_messages\x18\x03 \x01(\x05\x42\x03\xe0\x41\x02"L\n\x0cPullResponse\x12<\n\x11received_messages\x18\x01 \x03(\x0b\x32!.google.pubsub.v1.ReceivedMessage"\x95\x01\n\x18ModifyAckDeadlineRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x14\n\x07\x61\x63k_ids\x18\x04 \x03(\tB\x03\xe0\x41\x02\x12!\n\x14\x61\x63k_deadline_seconds\x18\x03 \x01(\x05\x42\x03\xe0\x41\x02"l\n\x12\x41\x63knowledgeRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x14\n\x07\x61\x63k_ids\x18\x02 \x03(\tB\x03\xe0\x41\x02"\xa9\x02\n\x14StreamingPullRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x0f\n\x07\x61\x63k_ids\x18\x02 \x03(\t\x12\x1f\n\x17modify_deadline_seconds\x18\x03 \x03(\x05\x12\x1f\n\x17modify_deadline_ack_ids\x18\x04 \x03(\t\x12(\n\x1bstream_ack_deadline_seconds\x18\x05 \x01(\x05\x42\x03\xe0\x41\x02\x12\x11\n\tclient_id\x18\x06 \x01(\t\x12 \n\x18max_outstanding_messages\x18\x07 \x01(\x03\x12\x1d\n\x15max_outstanding_bytes\x18\x08 \x01(\x03"U\n\x15StreamingPullResponse\x12<\n\x11received_messages\x18\x01 \x03(\x0b\x32!.google.pubsub.v1.ReceivedMessage"\x83\x02\n\x15\x43reateSnapshotRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1epubsub.googleapis.com/Snapshot\x12@\n\x0csubscription\x18\x02 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12\x43\n\x06labels\x18\x03 \x03(\x0b\x32\x33.google.pubsub.v1.CreateSnapshotRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x80\x01\n\x15UpdateSnapshotRequest\x12\x31\n\x08snapshot\x18\x01 \x01(\x0b\x32\x1a.google.pubsub.v1.SnapshotB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"\xaf\x02\n\x08Snapshot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x05topic\x18\x02 \x01(\tB \xfa\x41\x1d\n\x1bpubsub.googleapis.com/Topic\x12/\n\x0b\x65xpire_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x06labels\x18\x04 \x03(\x0b\x32&.google.pubsub.v1.Snapshot.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:L\xea\x41I\n\x1epubsub.googleapis.com/Snapshot\x12\'projects/{project}/snapshots/{snapshot}"N\n\x12GetSnapshotRequest\x12\x38\n\x08snapshot\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1epubsub.googleapis.com/Snapshot"\x83\x01\n\x14ListSnapshotsRequest\x12\x44\n\x07project\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+cloudresourcemanager.googleapis.com/Project\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"_\n\x15ListSnapshotsResponse\x12-\n\tsnapshots\x18\x01 \x03(\x0b\x32\x1a.google.pubsub.v1.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"Q\n\x15\x44\x65leteSnapshotRequest\x12\x38\n\x08snapshot\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1epubsub.googleapis.com/Snapshot"\xbe\x01\n\x0bSeekRequest\x12@\n\x0csubscription\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n"pubsub.googleapis.com/Subscription\x12*\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x37\n\x08snapshot\x18\x03 \x01(\tB#\xfa\x41 \n\x1epubsub.googleapis.com/SnapshotH\x00\x42\x08\n\x06target"\x0e\n\x0cSeekResponse2\xa3\x0b\n\tPublisher\x12q\n\x0b\x43reateTopic\x12\x17.google.pubsub.v1.Topic\x1a\x17.google.pubsub.v1.Topic"0\x82\xd3\xe4\x93\x02#\x1a\x1e/v1/{name=projects/*/topics/*}:\x01*\xda\x41\x04name\x12}\n\x0bUpdateTopic\x12$.google.pubsub.v1.UpdateTopicRequest\x1a\x17.google.pubsub.v1.Topic"/\x82\xd3\xe4\x93\x02)2$/v1/{topic.name=projects/*/topics/*}:\x01*\x12\x93\x01\n\x07Publish\x12 .google.pubsub.v1.PublishRequest\x1a!.google.pubsub.v1.PublishResponse"C\x82\xd3\xe4\x93\x02,"\'/v1/{topic=projects/*/topics/*}:publish:\x01*\xda\x41\x0etopic,messages\x12w\n\x08GetTopic\x12!.google.pubsub.v1.GetTopicRequest\x1a\x17.google.pubsub.v1.Topic"/\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{topic=projects/*/topics/*}\xda\x41\x05topic\x12\x8a\x01\n\nListTopics\x12#.google.pubsub.v1.ListTopicsRequest\x1a$.google.pubsub.v1.ListTopicsResponse"1\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{project=projects/*}/topics\xda\x41\x07project\x12\xba\x01\n\x16ListTopicSubscriptions\x12/.google.pubsub.v1.ListTopicSubscriptionsRequest\x1a\x30.google.pubsub.v1.ListTopicSubscriptionsResponse"=\x82\xd3\xe4\x93\x02/\x12-/v1/{topic=projects/*/topics/*}/subscriptions\xda\x41\x05topic\x12\xaa\x01\n\x12ListTopicSnapshots\x12+.google.pubsub.v1.ListTopicSnapshotsRequest\x1a,.google.pubsub.v1.ListTopicSnapshotsResponse"9\x82\xd3\xe4\x93\x02+\x12)/v1/{topic=projects/*/topics/*}/snapshots\xda\x41\x05topic\x12|\n\x0b\x44\x65leteTopic\x12$.google.pubsub.v1.DeleteTopicRequest\x1a\x16.google.protobuf.Empty"/\x82\xd3\xe4\x93\x02!*\x1f/v1/{topic=projects/*/topics/*}\xda\x41\x05topic\x12\xad\x01\n\x12\x44\x65tachSubscription\x12+.google.pubsub.v1.DetachSubscriptionRequest\x1a,.google.pubsub.v1.DetachSubscriptionResponse"<\x82\xd3\xe4\x93\x02\x36"4/v1/{subscription=projects/*/subscriptions/*}:detach\x1ap\xca\x41\x15pubsub.googleapis.com\xd2\x41Uhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/pubsub2\x83\x15\n\nSubscriber\x12\xb4\x01\n\x12\x43reateSubscription\x12\x1e.google.pubsub.v1.Subscription\x1a\x1e.google.pubsub.v1.Subscription"^\x82\xd3\xe4\x93\x02*\x1a%/v1/{name=projects/*/subscriptions/*}:\x01*\xda\x41+name,topic,push_config,ack_deadline_seconds\x12\xa1\x01\n\x0fGetSubscription\x12(.google.pubsub.v1.GetSubscriptionRequest\x1a\x1e.google.pubsub.v1.Subscription"D\x82\xd3\xe4\x93\x02/\x12-/v1/{subscription=projects/*/subscriptions/*}\xda\x41\x0csubscription\x12\xa0\x01\n\x12UpdateSubscription\x12+.google.pubsub.v1.UpdateSubscriptionRequest\x1a\x1e.google.pubsub.v1.Subscription"=\x82\xd3\xe4\x93\x02\x37\x32\x32/v1/{subscription.name=projects/*/subscriptions/*}:\x01*\x12\xa6\x01\n\x11ListSubscriptions\x12*.google.pubsub.v1.ListSubscriptionsRequest\x1a+.google.pubsub.v1.ListSubscriptionsResponse"8\x82\xd3\xe4\x93\x02(\x12&/v1/{project=projects/*}/subscriptions\xda\x41\x07project\x12\x9f\x01\n\x12\x44\x65leteSubscription\x12+.google.pubsub.v1.DeleteSubscriptionRequest\x1a\x16.google.protobuf.Empty"D\x82\xd3\xe4\x93\x02/*-/v1/{subscription=projects/*/subscriptions/*}\xda\x41\x0csubscription\x12\xcf\x01\n\x11ModifyAckDeadline\x12*.google.pubsub.v1.ModifyAckDeadlineRequest\x1a\x16.google.protobuf.Empty"v\x82\xd3\xe4\x93\x02\x44"?/v1/{subscription=projects/*/subscriptions/*}:modifyAckDeadline:\x01*\xda\x41)subscription,ack_ids,ack_deadline_seconds\x12\xa8\x01\n\x0b\x41\x63knowledge\x12$.google.pubsub.v1.AcknowledgeRequest\x1a\x16.google.protobuf.Empty"[\x82\xd3\xe4\x93\x02>"9/v1/{subscription=projects/*/subscriptions/*}:acknowledge:\x01*\xda\x41\x14subscription,ack_ids\x12\xb3\x01\n\x04Pull\x12\x1d.google.pubsub.v1.PullRequest\x1a\x1e.google.pubsub.v1.PullResponse"l\x82\xd3\xe4\x93\x02\x37"2/v1/{subscription=projects/*/subscriptions/*}:pull:\x01*\xda\x41,subscription,return_immediately,max_messages\x12\x66\n\rStreamingPull\x12&.google.pubsub.v1.StreamingPullRequest\x1a\'.google.pubsub.v1.StreamingPullResponse"\x00(\x01\x30\x01\x12\xbb\x01\n\x10ModifyPushConfig\x12).google.pubsub.v1.ModifyPushConfigRequest\x1a\x16.google.protobuf.Empty"d\x82\xd3\xe4\x93\x02\x43">/v1/{subscription=projects/*/subscriptions/*}:modifyPushConfig:\x01*\xda\x41\x18subscription,push_config\x12\x89\x01\n\x0bGetSnapshot\x12$.google.pubsub.v1.GetSnapshotRequest\x1a\x1a.google.pubsub.v1.Snapshot"8\x82\xd3\xe4\x93\x02\'\x12%/v1/{snapshot=projects/*/snapshots/*}\xda\x41\x08snapshot\x12\x96\x01\n\rListSnapshots\x12&.google.pubsub.v1.ListSnapshotsRequest\x1a\'.google.pubsub.v1.ListSnapshotsResponse"4\x82\xd3\xe4\x93\x02$\x12"/v1/{project=projects/*}/snapshots\xda\x41\x07project\x12\x97\x01\n\x0e\x43reateSnapshot\x12\'.google.pubsub.v1.CreateSnapshotRequest\x1a\x1a.google.pubsub.v1.Snapshot"@\x82\xd3\xe4\x93\x02&\x1a!/v1/{name=projects/*/snapshots/*}:\x01*\xda\x41\x11name,subscription\x12\x8c\x01\n\x0eUpdateSnapshot\x12\'.google.pubsub.v1.UpdateSnapshotRequest\x1a\x1a.google.pubsub.v1.Snapshot"5\x82\xd3\xe4\x93\x02/2*/v1/{snapshot.name=projects/*/snapshots/*}:\x01*\x12\x8b\x01\n\x0e\x44\x65leteSnapshot\x12\'.google.pubsub.v1.DeleteSnapshotRequest\x1a\x16.google.protobuf.Empty"8\x82\xd3\xe4\x93\x02\'*%/v1/{snapshot=projects/*/snapshots/*}\xda\x41\x08snapshot\x12\x84\x01\n\x04Seek\x12\x1d.google.pubsub.v1.SeekRequest\x1a\x1e.google.pubsub.v1.SeekResponse"=\x82\xd3\xe4\x93\x02\x37"2/v1/{subscription=projects/*/subscriptions/*}:seek:\x01*\x1ap\xca\x41\x15pubsub.googleapis.com\xd2\x41Uhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/pubsubB\xae\x01\n\x14\x63om.google.pubsub.v1B\x0bPubsubProtoP\x01Z6google.golang.org/genproto/googleapis/pubsub/v1;pubsub\xf8\x01\x01\xaa\x02\x16Google.Cloud.PubSub.V1\xca\x02\x16Google\\Cloud\\PubSub\\V1\xea\x02\x19Google::Cloud::PubSub::V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_MESSAGESTORAGEPOLICY = _descriptor.Descriptor(
    name="MessageStoragePolicy",
    full_name="google.pubsub.v1.MessageStoragePolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="allowed_persistence_regions",
            full_name="google.pubsub.v1.MessageStoragePolicy.allowed_persistence_regions",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=306,
    serialized_end=365,
)


_TOPIC_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.pubsub.v1.Topic.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.Topic.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.Topic.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=543,
    serialized_end=588,
)

_TOPIC = _descriptor.Descriptor(
    name="Topic",
    full_name="google.pubsub.v1.Topic",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.pubsub.v1.Topic.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.pubsub.v1.Topic.labels",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message_storage_policy",
            full_name="google.pubsub.v1.Topic.message_storage_policy",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kms_key_name",
            full_name="google.pubsub.v1.Topic.kms_key_name",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _TOPIC_LABELSENTRY,
    ],
    enum_types=[],
    serialized_options=b"\352AQ\n\033pubsub.googleapis.com/Topic\022!projects/{project}/topics/{topic}\022\017_deleted-topic_",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=368,
    serialized_end=674,
)


_PUBSUBMESSAGE_ATTRIBUTESENTRY = _descriptor.Descriptor(
    name="AttributesEntry",
    full_name="google.pubsub.v1.PubsubMessage.AttributesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.PubsubMessage.AttributesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.PubsubMessage.AttributesEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=869,
    serialized_end=918,
)

_PUBSUBMESSAGE = _descriptor.Descriptor(
    name="PubsubMessage",
    full_name="google.pubsub.v1.PubsubMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="data",
            full_name="google.pubsub.v1.PubsubMessage.data",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attributes",
            full_name="google.pubsub.v1.PubsubMessage.attributes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message_id",
            full_name="google.pubsub.v1.PubsubMessage.message_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="publish_time",
            full_name="google.pubsub.v1.PubsubMessage.publish_time",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ordering_key",
            full_name="google.pubsub.v1.PubsubMessage.ordering_key",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _PUBSUBMESSAGE_ATTRIBUTESENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=677,
    serialized_end=918,
)


_GETTOPICREQUEST = _descriptor.Descriptor(
    name="GetTopicRequest",
    full_name="google.pubsub.v1.GetTopicRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.GetTopicRequest.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=920,
    serialized_end=989,
)


_UPDATETOPICREQUEST = _descriptor.Descriptor(
    name="UpdateTopicRequest",
    full_name="google.pubsub.v1.UpdateTopicRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.UpdateTopicRequest.topic",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.pubsub.v1.UpdateTopicRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=991,
    serialized_end=1110,
)


_PUBLISHREQUEST = _descriptor.Descriptor(
    name="PublishRequest",
    full_name="google.pubsub.v1.PublishRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.PublishRequest.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="messages",
            full_name="google.pubsub.v1.PublishRequest.messages",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1112,
    serialized_end=1236,
)


_PUBLISHRESPONSE = _descriptor.Descriptor(
    name="PublishResponse",
    full_name="google.pubsub.v1.PublishResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message_ids",
            full_name="google.pubsub.v1.PublishResponse.message_ids",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1238,
    serialized_end=1276,
)


_LISTTOPICSREQUEST = _descriptor.Descriptor(
    name="ListTopicsRequest",
    full_name="google.pubsub.v1.ListTopicsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="project",
            full_name="google.pubsub.v1.ListTopicsRequest.project",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.pubsub.v1.ListTopicsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.pubsub.v1.ListTopicsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1279,
    serialized_end=1407,
)


_LISTTOPICSRESPONSE = _descriptor.Descriptor(
    name="ListTopicsResponse",
    full_name="google.pubsub.v1.ListTopicsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topics",
            full_name="google.pubsub.v1.ListTopicsResponse.topics",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.pubsub.v1.ListTopicsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1409,
    serialized_end=1495,
)


_LISTTOPICSUBSCRIPTIONSREQUEST = _descriptor.Descriptor(
    name="ListTopicSubscriptionsRequest",
    full_name="google.pubsub.v1.ListTopicSubscriptionsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.ListTopicSubscriptionsRequest.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.pubsub.v1.ListTopicSubscriptionsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.pubsub.v1.ListTopicSubscriptionsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1497,
    serialized_end=1619,
)


_LISTTOPICSUBSCRIPTIONSRESPONSE = _descriptor.Descriptor(
    name="ListTopicSubscriptionsResponse",
    full_name="google.pubsub.v1.ListTopicSubscriptionsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscriptions",
            full_name="google.pubsub.v1.ListTopicSubscriptionsResponse.subscriptions",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.pubsub.v1.ListTopicSubscriptionsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1621,
    serialized_end=1742,
)


_LISTTOPICSNAPSHOTSREQUEST = _descriptor.Descriptor(
    name="ListTopicSnapshotsRequest",
    full_name="google.pubsub.v1.ListTopicSnapshotsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.ListTopicSnapshotsRequest.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.pubsub.v1.ListTopicSnapshotsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.pubsub.v1.ListTopicSnapshotsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1744,
    serialized_end=1862,
)


_LISTTOPICSNAPSHOTSRESPONSE = _descriptor.Descriptor(
    name="ListTopicSnapshotsResponse",
    full_name="google.pubsub.v1.ListTopicSnapshotsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshots",
            full_name="google.pubsub.v1.ListTopicSnapshotsResponse.snapshots",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.pubsub.v1.ListTopicSnapshotsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1864,
    serialized_end=1936,
)


_DELETETOPICREQUEST = _descriptor.Descriptor(
    name="DeleteTopicRequest",
    full_name="google.pubsub.v1.DeleteTopicRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.DeleteTopicRequest.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1938,
    serialized_end=2010,
)


_DETACHSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
    name="DetachSubscriptionRequest",
    full_name="google.pubsub.v1.DetachSubscriptionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.DetachSubscriptionRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2012,
    serialized_end=2105,
)


_DETACHSUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
    name="DetachSubscriptionResponse",
    full_name="google.pubsub.v1.DetachSubscriptionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2107,
    serialized_end=2135,
)


_SUBSCRIPTION_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.pubsub.v1.Subscription.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.Subscription.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.Subscription.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=543,
    serialized_end=588,
)

_SUBSCRIPTION = _descriptor.Descriptor(
    name="Subscription",
    full_name="google.pubsub.v1.Subscription",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.pubsub.v1.Subscription.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.Subscription.topic",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="push_config",
            full_name="google.pubsub.v1.Subscription.push_config",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ack_deadline_seconds",
            full_name="google.pubsub.v1.Subscription.ack_deadline_seconds",
            index=3,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retain_acked_messages",
            full_name="google.pubsub.v1.Subscription.retain_acked_messages",
            index=4,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message_retention_duration",
            full_name="google.pubsub.v1.Subscription.message_retention_duration",
            index=5,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.pubsub.v1.Subscription.labels",
            index=6,
            number=9,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="enable_message_ordering",
            full_name="google.pubsub.v1.Subscription.enable_message_ordering",
            index=7,
            number=10,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="expiration_policy",
            full_name="google.pubsub.v1.Subscription.expiration_policy",
            index=8,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.pubsub.v1.Subscription.filter",
            index=9,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dead_letter_policy",
            full_name="google.pubsub.v1.Subscription.dead_letter_policy",
            index=10,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retry_policy",
            full_name="google.pubsub.v1.Subscription.retry_policy",
            index=11,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="detached",
            full_name="google.pubsub.v1.Subscription.detached",
            index=12,
            number=15,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _SUBSCRIPTION_LABELSENTRY,
    ],
    enum_types=[],
    serialized_options=b'\352AU\n"pubsub.googleapis.com/Subscription\022/projects/{project}/subscriptions/{subscription}',
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2138,
    serialized_end=2842,
)


_RETRYPOLICY = _descriptor.Descriptor(
    name="RetryPolicy",
    full_name="google.pubsub.v1.RetryPolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="minimum_backoff",
            full_name="google.pubsub.v1.RetryPolicy.minimum_backoff",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="maximum_backoff",
            full_name="google.pubsub.v1.RetryPolicy.maximum_backoff",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2844,
    serialized_end=2961,
)


_DEADLETTERPOLICY = _descriptor.Descriptor(
    name="DeadLetterPolicy",
    full_name="google.pubsub.v1.DeadLetterPolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="dead_letter_topic",
            full_name="google.pubsub.v1.DeadLetterPolicy.dead_letter_topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_delivery_attempts",
            full_name="google.pubsub.v1.DeadLetterPolicy.max_delivery_attempts",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2963,
    serialized_end=3039,
)


_EXPIRATIONPOLICY = _descriptor.Descriptor(
    name="ExpirationPolicy",
    full_name="google.pubsub.v1.ExpirationPolicy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ttl",
            full_name="google.pubsub.v1.ExpirationPolicy.ttl",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3041,
    serialized_end=3099,
)


_PUSHCONFIG_OIDCTOKEN = _descriptor.Descriptor(
    name="OidcToken",
    full_name="google.pubsub.v1.PushConfig.OidcToken",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="service_account_email",
            full_name="google.pubsub.v1.PushConfig.OidcToken.service_account_email",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="audience",
            full_name="google.pubsub.v1.PushConfig.OidcToken.audience",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3267,
    serialized_end=3327,
)

_PUSHCONFIG_ATTRIBUTESENTRY = _descriptor.Descriptor(
    name="AttributesEntry",
    full_name="google.pubsub.v1.PushConfig.AttributesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.PushConfig.AttributesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.PushConfig.AttributesEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=869,
    serialized_end=918,
)

_PUSHCONFIG = _descriptor.Descriptor(
    name="PushConfig",
    full_name="google.pubsub.v1.PushConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="push_endpoint",
            full_name="google.pubsub.v1.PushConfig.push_endpoint",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attributes",
            full_name="google.pubsub.v1.PushConfig.attributes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="oidc_token",
            full_name="google.pubsub.v1.PushConfig.oidc_token",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _PUSHCONFIG_OIDCTOKEN,
        _PUSHCONFIG_ATTRIBUTESENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="authentication_method",
            full_name="google.pubsub.v1.PushConfig.authentication_method",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=3102,
    serialized_end=3403,
)


_RECEIVEDMESSAGE = _descriptor.Descriptor(
    name="ReceivedMessage",
    full_name="google.pubsub.v1.ReceivedMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ack_id",
            full_name="google.pubsub.v1.ReceivedMessage.ack_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message",
            full_name="google.pubsub.v1.ReceivedMessage.message",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="delivery_attempt",
            full_name="google.pubsub.v1.ReceivedMessage.delivery_attempt",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3405,
    serialized_end=3514,
)


_GETSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
    name="GetSubscriptionRequest",
    full_name="google.pubsub.v1.GetSubscriptionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.GetSubscriptionRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3516,
    serialized_end=3606,
)


_UPDATESUBSCRIPTIONREQUEST = _descriptor.Descriptor(
    name="UpdateSubscriptionRequest",
    full_name="google.pubsub.v1.UpdateSubscriptionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.UpdateSubscriptionRequest.subscription",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.pubsub.v1.UpdateSubscriptionRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3609,
    serialized_end=3749,
)


_LISTSUBSCRIPTIONSREQUEST = _descriptor.Descriptor(
    name="ListSubscriptionsRequest",
    full_name="google.pubsub.v1.ListSubscriptionsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="project",
            full_name="google.pubsub.v1.ListSubscriptionsRequest.project",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.pubsub.v1.ListSubscriptionsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.pubsub.v1.ListSubscriptionsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3752,
    serialized_end=3887,
)


_LISTSUBSCRIPTIONSRESPONSE = _descriptor.Descriptor(
    name="ListSubscriptionsResponse",
    full_name="google.pubsub.v1.ListSubscriptionsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscriptions",
            full_name="google.pubsub.v1.ListSubscriptionsResponse.subscriptions",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.pubsub.v1.ListSubscriptionsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3889,
    serialized_end=3996,
)


_DELETESUBSCRIPTIONREQUEST = _descriptor.Descriptor(
    name="DeleteSubscriptionRequest",
    full_name="google.pubsub.v1.DeleteSubscriptionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.DeleteSubscriptionRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3998,
    serialized_end=4091,
)


_MODIFYPUSHCONFIGREQUEST = _descriptor.Descriptor(
    name="ModifyPushConfigRequest",
    full_name="google.pubsub.v1.ModifyPushConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.ModifyPushConfigRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="push_config",
            full_name="google.pubsub.v1.ModifyPushConfigRequest.push_config",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4094,
    serialized_end=4241,
)


_PULLREQUEST = _descriptor.Descriptor(
    name="PullRequest",
    full_name="google.pubsub.v1.PullRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.PullRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="return_immediately",
            full_name="google.pubsub.v1.PullRequest.return_immediately",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001\340A\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_messages",
            full_name="google.pubsub.v1.PullRequest.max_messages",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4244,
    serialized_end=4385,
)


_PULLRESPONSE = _descriptor.Descriptor(
    name="PullResponse",
    full_name="google.pubsub.v1.PullResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="received_messages",
            full_name="google.pubsub.v1.PullResponse.received_messages",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4387,
    serialized_end=4463,
)


_MODIFYACKDEADLINEREQUEST = _descriptor.Descriptor(
    name="ModifyAckDeadlineRequest",
    full_name="google.pubsub.v1.ModifyAckDeadlineRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.ModifyAckDeadlineRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ack_ids",
            full_name="google.pubsub.v1.ModifyAckDeadlineRequest.ack_ids",
            index=1,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ack_deadline_seconds",
            full_name="google.pubsub.v1.ModifyAckDeadlineRequest.ack_deadline_seconds",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4466,
    serialized_end=4615,
)


_ACKNOWLEDGEREQUEST = _descriptor.Descriptor(
    name="AcknowledgeRequest",
    full_name="google.pubsub.v1.AcknowledgeRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.AcknowledgeRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ack_ids",
            full_name="google.pubsub.v1.AcknowledgeRequest.ack_ids",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4617,
    serialized_end=4725,
)


_STREAMINGPULLREQUEST = _descriptor.Descriptor(
    name="StreamingPullRequest",
    full_name="google.pubsub.v1.StreamingPullRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.StreamingPullRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="ack_ids",
            full_name="google.pubsub.v1.StreamingPullRequest.ack_ids",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="modify_deadline_seconds",
            full_name="google.pubsub.v1.StreamingPullRequest.modify_deadline_seconds",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="modify_deadline_ack_ids",
            full_name="google.pubsub.v1.StreamingPullRequest.modify_deadline_ack_ids",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="stream_ack_deadline_seconds",
            full_name="google.pubsub.v1.StreamingPullRequest.stream_ack_deadline_seconds",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="client_id",
            full_name="google.pubsub.v1.StreamingPullRequest.client_id",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_outstanding_messages",
            full_name="google.pubsub.v1.StreamingPullRequest.max_outstanding_messages",
            index=6,
            number=7,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_outstanding_bytes",
            full_name="google.pubsub.v1.StreamingPullRequest.max_outstanding_bytes",
            index=7,
            number=8,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4728,
    serialized_end=5025,
)


_STREAMINGPULLRESPONSE = _descriptor.Descriptor(
    name="StreamingPullResponse",
    full_name="google.pubsub.v1.StreamingPullResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="received_messages",
            full_name="google.pubsub.v1.StreamingPullResponse.received_messages",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5027,
    serialized_end=5112,
)


_CREATESNAPSHOTREQUEST_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.pubsub.v1.CreateSnapshotRequest.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.CreateSnapshotRequest.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.CreateSnapshotRequest.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=543,
    serialized_end=588,
)

_CREATESNAPSHOTREQUEST = _descriptor.Descriptor(
    name="CreateSnapshotRequest",
    full_name="google.pubsub.v1.CreateSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.pubsub.v1.CreateSnapshotRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036pubsub.googleapis.com/Snapshot",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.CreateSnapshotRequest.subscription",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.pubsub.v1.CreateSnapshotRequest.labels",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _CREATESNAPSHOTREQUEST_LABELSENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5115,
    serialized_end=5374,
)


_UPDATESNAPSHOTREQUEST = _descriptor.Descriptor(
    name="UpdateSnapshotRequest",
    full_name="google.pubsub.v1.UpdateSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="google.pubsub.v1.UpdateSnapshotRequest.snapshot",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.pubsub.v1.UpdateSnapshotRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5377,
    serialized_end=5505,
)


_SNAPSHOT_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="google.pubsub.v1.Snapshot.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.pubsub.v1.Snapshot.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.pubsub.v1.Snapshot.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=543,
    serialized_end=588,
)

_SNAPSHOT = _descriptor.Descriptor(
    name="Snapshot",
    full_name="google.pubsub.v1.Snapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.pubsub.v1.Snapshot.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.pubsub.v1.Snapshot.topic",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\372A\035\n\033pubsub.googleapis.com/Topic",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="expire_time",
            full_name="google.pubsub.v1.Snapshot.expire_time",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="google.pubsub.v1.Snapshot.labels",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[
        _SNAPSHOT_LABELSENTRY,
    ],
    enum_types=[],
    serialized_options=b"\352AI\n\036pubsub.googleapis.com/Snapshot\022'projects/{project}/snapshots/{snapshot}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5508,
    serialized_end=5811,
)


_GETSNAPSHOTREQUEST = _descriptor.Descriptor(
    name="GetSnapshotRequest",
    full_name="google.pubsub.v1.GetSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="google.pubsub.v1.GetSnapshotRequest.snapshot",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036pubsub.googleapis.com/Snapshot",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5813,
    serialized_end=5891,
)


_LISTSNAPSHOTSREQUEST = _descriptor.Descriptor(
    name="ListSnapshotsRequest",
    full_name="google.pubsub.v1.ListSnapshotsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="project",
            full_name="google.pubsub.v1.ListSnapshotsRequest.project",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+cloudresourcemanager.googleapis.com/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.pubsub.v1.ListSnapshotsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.pubsub.v1.ListSnapshotsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5894,
    serialized_end=6025,
)


_LISTSNAPSHOTSRESPONSE = _descriptor.Descriptor(
    name="ListSnapshotsResponse",
    full_name="google.pubsub.v1.ListSnapshotsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshots",
            full_name="google.pubsub.v1.ListSnapshotsResponse.snapshots",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.pubsub.v1.ListSnapshotsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6027,
    serialized_end=6122,
)


_DELETESNAPSHOTREQUEST = _descriptor.Descriptor(
    name="DeleteSnapshotRequest",
    full_name="google.pubsub.v1.DeleteSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="google.pubsub.v1.DeleteSnapshotRequest.snapshot",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036pubsub.googleapis.com/Snapshot",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6124,
    serialized_end=6205,
)


_SEEKREQUEST = _descriptor.Descriptor(
    name="SeekRequest",
    full_name="google.pubsub.v1.SeekRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="subscription",
            full_name="google.pubsub.v1.SeekRequest.subscription",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A$\n"pubsub.googleapis.com/Subscription',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="time",
            full_name="google.pubsub.v1.SeekRequest.time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="google.pubsub.v1.SeekRequest.snapshot",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\372A \n\036pubsub.googleapis.com/Snapshot",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="target",
            full_name="google.pubsub.v1.SeekRequest.target",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=6208,
    serialized_end=6398,
)


_SEEKRESPONSE = _descriptor.Descriptor(
    name="SeekResponse",
    full_name="google.pubsub.v1.SeekResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6400,
    serialized_end=6414,
)

_TOPIC_LABELSENTRY.containing_type = _TOPIC
_TOPIC.fields_by_name["labels"].message_type = _TOPIC_LABELSENTRY
_TOPIC.fields_by_name["message_storage_policy"].message_type = _MESSAGESTORAGEPOLICY
_PUBSUBMESSAGE_ATTRIBUTESENTRY.containing_type = _PUBSUBMESSAGE
_PUBSUBMESSAGE.fields_by_name[
    "attributes"
].message_type = _PUBSUBMESSAGE_ATTRIBUTESENTRY
_PUBSUBMESSAGE.fields_by_name[
    "publish_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPDATETOPICREQUEST.fields_by_name["topic"].message_type = _TOPIC
_UPDATETOPICREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_PUBLISHREQUEST.fields_by_name["messages"].message_type = _PUBSUBMESSAGE
_LISTTOPICSRESPONSE.fields_by_name["topics"].message_type = _TOPIC
_SUBSCRIPTION_LABELSENTRY.containing_type = _SUBSCRIPTION
_SUBSCRIPTION.fields_by_name["push_config"].message_type = _PUSHCONFIG
_SUBSCRIPTION.fields_by_name[
    "message_retention_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SUBSCRIPTION.fields_by_name["labels"].message_type = _SUBSCRIPTION_LABELSENTRY
_SUBSCRIPTION.fields_by_name["expiration_policy"].message_type = _EXPIRATIONPOLICY
_SUBSCRIPTION.fields_by_name["dead_letter_policy"].message_type = _DEADLETTERPOLICY
_SUBSCRIPTION.fields_by_name["retry_policy"].message_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name[
    "minimum_backoff"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RETRYPOLICY.fields_by_name[
    "maximum_backoff"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXPIRATIONPOLICY.fields_by_name[
    "ttl"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PUSHCONFIG_OIDCTOKEN.containing_type = _PUSHCONFIG
_PUSHCONFIG_ATTRIBUTESENTRY.containing_type = _PUSHCONFIG
_PUSHCONFIG.fields_by_name["attributes"].message_type = _PUSHCONFIG_ATTRIBUTESENTRY
_PUSHCONFIG.fields_by_name["oidc_token"].message_type = _PUSHCONFIG_OIDCTOKEN
_PUSHCONFIG.oneofs_by_name["authentication_method"].fields.append(
    _PUSHCONFIG.fields_by_name["oidc_token"]
)
_PUSHCONFIG.fields_by_name["oidc_token"].containing_oneof = _PUSHCONFIG.oneofs_by_name[
    "authentication_method"
]
_RECEIVEDMESSAGE.fields_by_name["message"].message_type = _PUBSUBMESSAGE
_UPDATESUBSCRIPTIONREQUEST.fields_by_name["subscription"].message_type = _SUBSCRIPTION
_UPDATESUBSCRIPTIONREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTSUBSCRIPTIONSRESPONSE.fields_by_name["subscriptions"].message_type = _SUBSCRIPTION
_MODIFYPUSHCONFIGREQUEST.fields_by_name["push_config"].message_type = _PUSHCONFIG
_PULLRESPONSE.fields_by_name["received_messages"].message_type = _RECEIVEDMESSAGE
_STREAMINGPULLRESPONSE.fields_by_name[
    "received_messages"
].message_type = _RECEIVEDMESSAGE
_CREATESNAPSHOTREQUEST_LABELSENTRY.containing_type = _CREATESNAPSHOTREQUEST
_CREATESNAPSHOTREQUEST.fields_by_name[
    "labels"
].message_type = _CREATESNAPSHOTREQUEST_LABELSENTRY
_UPDATESNAPSHOTREQUEST.fields_by_name["snapshot"].message_type = _SNAPSHOT
_UPDATESNAPSHOTREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_SNAPSHOT_LABELSENTRY.containing_type = _SNAPSHOT
_SNAPSHOT.fields_by_name[
    "expire_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SNAPSHOT.fields_by_name["labels"].message_type = _SNAPSHOT_LABELSENTRY
_LISTSNAPSHOTSRESPONSE.fields_by_name["snapshots"].message_type = _SNAPSHOT
_SEEKREQUEST.fields_by_name[
    "time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SEEKREQUEST.oneofs_by_name["target"].fields.append(_SEEKREQUEST.fields_by_name["time"])
_SEEKREQUEST.fields_by_name["time"].containing_oneof = _SEEKREQUEST.oneofs_by_name[
    "target"
]
_SEEKREQUEST.oneofs_by_name["target"].fields.append(
    _SEEKREQUEST.fields_by_name["snapshot"]
)
_SEEKREQUEST.fields_by_name["snapshot"].containing_oneof = _SEEKREQUEST.oneofs_by_name[
    "target"
]
DESCRIPTOR.message_types_by_name["MessageStoragePolicy"] = _MESSAGESTORAGEPOLICY
DESCRIPTOR.message_types_by_name["Topic"] = _TOPIC
DESCRIPTOR.message_types_by_name["PubsubMessage"] = _PUBSUBMESSAGE
DESCRIPTOR.message_types_by_name["GetTopicRequest"] = _GETTOPICREQUEST
DESCRIPTOR.message_types_by_name["UpdateTopicRequest"] = _UPDATETOPICREQUEST
DESCRIPTOR.message_types_by_name["PublishRequest"] = _PUBLISHREQUEST
DESCRIPTOR.message_types_by_name["PublishResponse"] = _PUBLISHRESPONSE
DESCRIPTOR.message_types_by_name["ListTopicsRequest"] = _LISTTOPICSREQUEST
DESCRIPTOR.message_types_by_name["ListTopicsResponse"] = _LISTTOPICSRESPONSE
DESCRIPTOR.message_types_by_name[
    "ListTopicSubscriptionsRequest"
] = _LISTTOPICSUBSCRIPTIONSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListTopicSubscriptionsResponse"
] = _LISTTOPICSUBSCRIPTIONSRESPONSE
DESCRIPTOR.message_types_by_name[
    "ListTopicSnapshotsRequest"
] = _LISTTOPICSNAPSHOTSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListTopicSnapshotsResponse"
] = _LISTTOPICSNAPSHOTSRESPONSE
DESCRIPTOR.message_types_by_name["DeleteTopicRequest"] = _DELETETOPICREQUEST
DESCRIPTOR.message_types_by_name[
    "DetachSubscriptionRequest"
] = _DETACHSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name[
    "DetachSubscriptionResponse"
] = _DETACHSUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name["Subscription"] = _SUBSCRIPTION
DESCRIPTOR.message_types_by_name["RetryPolicy"] = _RETRYPOLICY
DESCRIPTOR.message_types_by_name["DeadLetterPolicy"] = _DEADLETTERPOLICY
DESCRIPTOR.message_types_by_name["ExpirationPolicy"] = _EXPIRATIONPOLICY
DESCRIPTOR.message_types_by_name["PushConfig"] = _PUSHCONFIG
DESCRIPTOR.message_types_by_name["ReceivedMessage"] = _RECEIVEDMESSAGE
DESCRIPTOR.message_types_by_name["GetSubscriptionRequest"] = _GETSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateSubscriptionRequest"
] = _UPDATESUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name["ListSubscriptionsRequest"] = _LISTSUBSCRIPTIONSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListSubscriptionsResponse"
] = _LISTSUBSCRIPTIONSRESPONSE
DESCRIPTOR.message_types_by_name[
    "DeleteSubscriptionRequest"
] = _DELETESUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name["ModifyPushConfigRequest"] = _MODIFYPUSHCONFIGREQUEST
DESCRIPTOR.message_types_by_name["PullRequest"] = _PULLREQUEST
DESCRIPTOR.message_types_by_name["PullResponse"] = _PULLRESPONSE
DESCRIPTOR.message_types_by_name["ModifyAckDeadlineRequest"] = _MODIFYACKDEADLINEREQUEST
DESCRIPTOR.message_types_by_name["AcknowledgeRequest"] = _ACKNOWLEDGEREQUEST
DESCRIPTOR.message_types_by_name["StreamingPullRequest"] = _STREAMINGPULLREQUEST
DESCRIPTOR.message_types_by_name["StreamingPullResponse"] = _STREAMINGPULLRESPONSE
DESCRIPTOR.message_types_by_name["CreateSnapshotRequest"] = _CREATESNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name["UpdateSnapshotRequest"] = _UPDATESNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name["Snapshot"] = _SNAPSHOT
DESCRIPTOR.message_types_by_name["GetSnapshotRequest"] = _GETSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name["ListSnapshotsRequest"] = _LISTSNAPSHOTSREQUEST
DESCRIPTOR.message_types_by_name["ListSnapshotsResponse"] = _LISTSNAPSHOTSRESPONSE
DESCRIPTOR.message_types_by_name["DeleteSnapshotRequest"] = _DELETESNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name["SeekRequest"] = _SEEKREQUEST
DESCRIPTOR.message_types_by_name["SeekResponse"] = _SEEKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MessageStoragePolicy = _reflection.GeneratedProtocolMessageType(
    "MessageStoragePolicy",
    (_message.Message,),
    {
        "DESCRIPTOR": _MESSAGESTORAGEPOLICY,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A policy constraining the storage of messages published to the topic.

  
  Attributes:
      allowed_persistence_regions:
          A list of IDs of GCP regions where messages that are published
          to the topic may be persisted in storage. Messages published
          by publishers running in non-allowed GCP regions (or running
          outside of GCP altogether) will be routed for storage in one
          of the allowed regions. An empty list means that no regions
          are allowed, and is not a valid configuration.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.MessageStoragePolicy)
    },
)
_sym_db.RegisterMessage(MessageStoragePolicy)

Topic = _reflection.GeneratedProtocolMessageType(
    "Topic",
    (_message.Message,),
    {
        "LabelsEntry": _reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TOPIC_LABELSENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.Topic.LabelsEntry)
            },
        ),
        "DESCRIPTOR": _TOPIC,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A topic resource.

  
  Attributes:
      name:
          Required. The name of the topic. It must have the format
          ``"projects/{project}/topics/{topic}"``. ``{topic}`` must
          start with a letter, and contain only letters (``[A-Za-z]``),
          numbers (``[0-9]``), dashes (``-``), underscores (``_``),
          periods (``.``), tildes (``~``), plus (``+``) or percent signs
          (``%``). It must be between 3 and 255 characters in length,
          and it must not start with ``"goog"``.
      labels:
          See Creating and managing labels.
      message_storage_policy:
          Policy constraining the set of Google Cloud Platform regions
          where messages published to the topic may be stored. If not
          present, then no constraints are in effect.
      kms_key_name:
          The resource name of the Cloud KMS CryptoKey to be used to
          protect access to messages published on this topic.  The
          expected format is
          ``projects/*/locations/*/keyRings/*/cryptoKeys/*``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.Topic)
    },
)
_sym_db.RegisterMessage(Topic)
_sym_db.RegisterMessage(Topic.LabelsEntry)

PubsubMessage = _reflection.GeneratedProtocolMessageType(
    "PubsubMessage",
    (_message.Message,),
    {
        "AttributesEntry": _reflection.GeneratedProtocolMessageType(
            "AttributesEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _PUBSUBMESSAGE_ATTRIBUTESENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.PubsubMessage.AttributesEntry)
            },
        ),
        "DESCRIPTOR": _PUBSUBMESSAGE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A message that is published by publishers and consumed by subscribers.
  The message must contain either a non-empty data field or at least one
  attribute. Note that client libraries represent this object
  differently depending on the language. See the corresponding client
  library documentation for more information. See Quotas and limits for
  more information about message limits.

  
  Attributes:
      data:
          The message data field. If this field is empty, the message
          must contain at least one attribute.
      attributes:
          Attributes for this message. If this field is empty, the
          message must contain non-empty data. This can be used to
          filter messages on the subscription.
      message_id:
          ID of this message, assigned by the server when the message is
          published. Guaranteed to be unique within the topic. This
          value may be read by a subscriber that receives a
          ``PubsubMessage`` via a ``Pull`` call or a push delivery. It
          must not be populated by the publisher in a ``Publish`` call.
      publish_time:
          The time at which the message was published, populated by the
          server when it receives the ``Publish`` call. It must not be
          populated by the publisher in a ``Publish`` call.
      ordering_key:
          If non-empty, identifies related messages for which publish
          order should be respected. If a ``Subscription`` has
          ``enable_message_ordering`` set to ``true``, messages
          published with the same non-empty ``ordering_key`` value will
          be delivered to subscribers in the order in which they are
          received by the Pub/Sub system. All ``PubsubMessage``\ s
          published in a given ``PublishRequest`` must specify the same
          ``ordering_key`` value. EXPERIMENTAL: This feature is part of
          a closed alpha release. This API might be changed in backward-
          incompatible ways and is not recommended for production use.
          It is not subject to any SLA or deprecation policy.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PubsubMessage)
    },
)
_sym_db.RegisterMessage(PubsubMessage)
_sym_db.RegisterMessage(PubsubMessage.AttributesEntry)

GetTopicRequest = _reflection.GeneratedProtocolMessageType(
    "GetTopicRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTOPICREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the GetTopic method.

  
  Attributes:
      topic:
          Required. The name of the topic to get. Format is
          ``projects/{project}/topics/{topic}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.GetTopicRequest)
    },
)
_sym_db.RegisterMessage(GetTopicRequest)

UpdateTopicRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTopicRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETOPICREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the UpdateTopic method.

  
  Attributes:
      topic:
          Required. The updated topic object.
      update_mask:
          Required. Indicates which fields in the provided topic to
          update. Must be specified and non-empty. Note that if
          ``update_mask`` contains “message_storage_policy” but the
          ``message_storage_policy`` is not set in the ``topic``
          provided above, then the updated value is determined by the
          policy configured at the project or organization level.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.UpdateTopicRequest)
    },
)
_sym_db.RegisterMessage(UpdateTopicRequest)

PublishRequest = _reflection.GeneratedProtocolMessageType(
    "PublishRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the Publish method.

  
  Attributes:
      topic:
          Required. The messages in the request will be published on
          this topic. Format is ``projects/{project}/topics/{topic}``.
      messages:
          Required. The messages to publish.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PublishRequest)
    },
)
_sym_db.RegisterMessage(PublishRequest)

PublishResponse = _reflection.GeneratedProtocolMessageType(
    "PublishResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBLISHRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``Publish`` method.

  
  Attributes:
      message_ids:
          The server-assigned ID of each published message, in the same
          order as the messages in the request. IDs are guaranteed to be
          unique within the topic.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PublishResponse)
    },
)
_sym_db.RegisterMessage(PublishResponse)

ListTopicsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTopicsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``ListTopics`` method.

  
  Attributes:
      project:
          Required. The name of the project in which to list topics.
          Format is ``projects/{project-id}``.
      page_size:
          Maximum number of topics to return.
      page_token:
          The value returned by the last ``ListTopicsResponse``;
          indicates that this is a continuation of a prior
          ``ListTopics`` call, and that the system should return the
          next page of data.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicsRequest)
    },
)
_sym_db.RegisterMessage(ListTopicsRequest)

ListTopicsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTopicsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``ListTopics`` method.

  
  Attributes:
      topics:
          The resulting topics.
      next_page_token:
          If not empty, indicates that there may be more topics that
          match the request; this value should be passed in a new
          ``ListTopicsRequest``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicsResponse)
    },
)
_sym_db.RegisterMessage(ListTopicsResponse)

ListTopicSubscriptionsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTopicSubscriptionsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSUBSCRIPTIONSREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``ListTopicSubscriptions`` method.

  
  Attributes:
      topic:
          Required. The name of the topic that subscriptions are
          attached to. Format is ``projects/{project}/topics/{topic}``.
      page_size:
          Maximum number of subscription names to return.
      page_token:
          The value returned by the last
          ``ListTopicSubscriptionsResponse``; indicates that this is a
          continuation of a prior ``ListTopicSubscriptions`` call, and
          that the system should return the next page of data.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicSubscriptionsRequest)
    },
)
_sym_db.RegisterMessage(ListTopicSubscriptionsRequest)

ListTopicSubscriptionsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTopicSubscriptionsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSUBSCRIPTIONSRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``ListTopicSubscriptions`` method.

  
  Attributes:
      subscriptions:
          The names of subscriptions attached to the topic specified in
          the request.
      next_page_token:
          If not empty, indicates that there may be more subscriptions
          that match the request; this value should be passed in a new
          ``ListTopicSubscriptionsRequest`` to get more subscriptions.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicSubscriptionsResponse)
    },
)
_sym_db.RegisterMessage(ListTopicSubscriptionsResponse)

ListTopicSnapshotsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTopicSnapshotsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSNAPSHOTSREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``ListTopicSnapshots`` method.

  
  Attributes:
      topic:
          Required. The name of the topic that snapshots are attached
          to. Format is ``projects/{project}/topics/{topic}``.
      page_size:
          Maximum number of snapshot names to return.
      page_token:
          The value returned by the last ``ListTopicSnapshotsResponse``;
          indicates that this is a continuation of a prior
          ``ListTopicSnapshots`` call, and that the system should return
          the next page of data.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicSnapshotsRequest)
    },
)
_sym_db.RegisterMessage(ListTopicSnapshotsRequest)

ListTopicSnapshotsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTopicSnapshotsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTOPICSNAPSHOTSRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``ListTopicSnapshots`` method.

  
  Attributes:
      snapshots:
          The names of the snapshots that match the request.
      next_page_token:
          If not empty, indicates that there may be more snapshots that
          match the request; this value should be passed in a new
          ``ListTopicSnapshotsRequest`` to get more snapshots.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListTopicSnapshotsResponse)
    },
)
_sym_db.RegisterMessage(ListTopicSnapshotsResponse)

DeleteTopicRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTopicRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETOPICREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``DeleteTopic`` method.

  
  Attributes:
      topic:
          Required. Name of the topic to delete. Format is
          ``projects/{project}/topics/{topic}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DeleteTopicRequest)
    },
)
_sym_db.RegisterMessage(DeleteTopicRequest)

DetachSubscriptionRequest = _reflection.GeneratedProtocolMessageType(
    "DetachSubscriptionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DETACHSUBSCRIPTIONREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the DetachSubscription method.

  
  Attributes:
      subscription:
          Required. The subscription to detach. Format is
          ``projects/{project}/subscriptions/{subscription}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DetachSubscriptionRequest)
    },
)
_sym_db.RegisterMessage(DetachSubscriptionRequest)

DetachSubscriptionResponse = _reflection.GeneratedProtocolMessageType(
    "DetachSubscriptionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _DETACHSUBSCRIPTIONRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the DetachSubscription method. Reserved for future use.""",
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DetachSubscriptionResponse)
    },
)
_sym_db.RegisterMessage(DetachSubscriptionResponse)

Subscription = _reflection.GeneratedProtocolMessageType(
    "Subscription",
    (_message.Message,),
    {
        "LabelsEntry": _reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _SUBSCRIPTION_LABELSENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.Subscription.LabelsEntry)
            },
        ),
        "DESCRIPTOR": _SUBSCRIPTION,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A subscription resource.

  
  Attributes:
      name:
          Required. The name of the subscription. It must have the
          format ``"projects/{project}/subscriptions/{subscription}"``.
          ``{subscription}`` must start with a letter, and contain only
          letters (``[A-Za-z]``), numbers (``[0-9]``), dashes (``-``),
          underscores (``_``), periods (``.``), tildes (``~``), plus
          (``+``) or percent signs (``%``). It must be between 3 and 255
          characters in length, and it must not start with ``"goog"``.
      topic:
          Required. The name of the topic from which this subscription
          is receiving messages. Format is
          ``projects/{project}/topics/{topic}``. The value of this field
          will be ``_deleted-topic_`` if the topic has been deleted.
      push_config:
          If push delivery is used with this subscription, this field is
          used to configure it. An empty ``pushConfig`` signifies that
          the subscriber will pull and ack messages using API methods.
      ack_deadline_seconds:
          The approximate amount of time (on a best-effort basis)
          Pub/Sub waits for the subscriber to acknowledge receipt before
          resending the message. In the interval after the message is
          delivered and before it is acknowledged, it is considered to
          be outstanding. During that time period, the message will not
          be redelivered (on a best-effort basis).  For pull
          subscriptions, this value is used as the initial value for the
          ack deadline. To override this value for a given message, call
          ``ModifyAckDeadline`` with the corresponding ``ack_id`` if
          using non-streaming pull or send the ``ack_id`` in a
          ``StreamingModifyAckDeadlineRequest`` if using streaming pull.
          The minimum custom deadline you can specify is 10 seconds. The
          maximum custom deadline you can specify is 600 seconds (10
          minutes). If this parameter is 0, a default value of 10
          seconds is used.  For push delivery, this value is also used
          to set the request timeout for the call to the push endpoint.
          If the subscriber never acknowledges the message, the Pub/Sub
          system will eventually redeliver the message.
      retain_acked_messages:
          Indicates whether to retain acknowledged messages. If true,
          then messages are not expunged from the subscription’s
          backlog, even if they are acknowledged, until they fall out of
          the ``message_retention_duration`` window. This must be true
          if you would like to Seek to a timestamp.
      message_retention_duration:
          How long to retain unacknowledged messages in the
          subscription’s backlog, from the moment a message is
          published. If ``retain_acked_messages`` is true, then this
          also configures the retention of acknowledged messages, and
          thus configures how far back in time a ``Seek`` can be done.
          Defaults to 7 days. Cannot be more than 7 days or less than 10
          minutes.
      labels:
          See Creating and managing labels.
      enable_message_ordering:
          If true, messages published with the same ``ordering_key`` in
          ``PubsubMessage`` will be delivered to the subscribers in the
          order in which they are received by the Pub/Sub system.
          Otherwise, they may be delivered in any order. EXPERIMENTAL:
          This feature is part of a closed alpha release. This API might
          be changed in backward-incompatible ways and is not
          recommended for production use. It is not subject to any SLA
          or deprecation policy.
      expiration_policy:
          A policy that specifies the conditions for this subscription’s
          expiration. A subscription is considered active as long as any
          connected subscriber is successfully consuming messages from
          the subscription or is issuing operations on the subscription.
          If ``expiration_policy`` is not set, a *default policy* with
          ``ttl`` of 31 days will be used. The minimum allowed value for
          ``expiration_policy.ttl`` is 1 day.
      filter:
          An expression written in the Pub/Sub `filter language
          <https://cloud.google.com/pubsub/docs/filtering>`__. If non-
          empty, then only ``PubsubMessage``\ s whose ``attributes``
          field matches the filter are delivered on this subscription.
          If empty, then no messages are filtered out.
      dead_letter_policy:
          A policy that specifies the conditions for dead lettering
          messages in this subscription. If dead_letter_policy is not
          set, dead lettering is disabled.  The Cloud Pub/Sub service
          account associated with this subscriptions’s parent project
          (i.e., service-{project_number}@gcp-sa-
          pubsub.iam.gserviceaccount.com) must have permission to
          Acknowledge() messages on this subscription.
      retry_policy:
          A policy that specifies how Pub/Sub retries message delivery
          for this subscription.  If not set, the default retry policy
          is applied. This generally implies that messages will be
          retried as soon as possible for healthy subscribers.
          RetryPolicy will be triggered on NACKs or acknowledgement
          deadline exceeded events for a given message.
      detached:
          Indicates whether the subscription is detached from its topic.
          Detached subscriptions don’t receive messages from their topic
          and don’t retain any backlog. ``Pull`` and ``StreamingPull``
          requests will return FAILED_PRECONDITION. If the subscription
          is a push subscription, pushes to the endpoint will not be
          made.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.Subscription)
    },
)
_sym_db.RegisterMessage(Subscription)
_sym_db.RegisterMessage(Subscription.LabelsEntry)

RetryPolicy = _reflection.GeneratedProtocolMessageType(
    "RetryPolicy",
    (_message.Message,),
    {
        "DESCRIPTOR": _RETRYPOLICY,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A policy that specifies how Cloud Pub/Sub retries message delivery.
  Retry delay will be exponential based on provided minimum and maximum
  backoffs. https://en.wikipedia.org/wiki/Exponential_backoff.
  RetryPolicy will be triggered on NACKs or acknowledgement deadline
  exceeded events for a given message.  Retry Policy is implemented on a
  best effort basis. At times, the delay between consecutive deliveries
  may not match the configuration. That is, delay can be more or less
  than configured backoff.

  
  Attributes:
      minimum_backoff:
          The minimum delay between consecutive deliveries of a given
          message. Value should be between 0 and 600 seconds. Defaults
          to 10 seconds.
      maximum_backoff:
          The maximum delay between consecutive deliveries of a given
          message. Value should be between 0 and 600 seconds. Defaults
          to 600 seconds.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.RetryPolicy)
    },
)
_sym_db.RegisterMessage(RetryPolicy)

DeadLetterPolicy = _reflection.GeneratedProtocolMessageType(
    "DeadLetterPolicy",
    (_message.Message,),
    {
        "DESCRIPTOR": _DEADLETTERPOLICY,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Dead lettering is done on a best effort basis. The same message might
  be dead lettered multiple times.  If validation on any of the fields
  fails at subscription creation/updation, the create/update
  subscription request will fail.

  
  Attributes:
      dead_letter_topic:
          The name of the topic to which dead letter messages should be
          published. Format is ``projects/{project}/topics/{topic}``.The
          Cloud Pub/Sub service account associated with the enclosing
          subscription’s parent project (i.e.,
          service-{project_number}@gcp-sa-
          pubsub.iam.gserviceaccount.com) must have permission to
          Publish() to this topic.  The operation will fail if the topic
          does not exist. Users should ensure that there is a
          subscription attached to this topic since messages published
          to a topic with no subscriptions are lost.
      max_delivery_attempts:
          The maximum number of delivery attempts for any message. The
          value must be between 5 and 100.  The number of delivery
          attempts is defined as 1 + (the sum of number of NACKs and
          number of times the acknowledgement deadline has been exceeded
          for the message).  A NACK is any call to ModifyAckDeadline
          with a 0 deadline. Note that client libraries may
          automatically extend ack_deadlines.  This field will be
          honored on a best effort basis.  If this parameter is 0, a
          default value of 5 is used.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DeadLetterPolicy)
    },
)
_sym_db.RegisterMessage(DeadLetterPolicy)

ExpirationPolicy = _reflection.GeneratedProtocolMessageType(
    "ExpirationPolicy",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPIRATIONPOLICY,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A policy that specifies the conditions for resource expiration (i.e.,
  automatic resource deletion).

  
  Attributes:
      ttl:
          Specifies the “time-to-live” duration for an associated
          resource. The resource expires if it is not active for a
          period of ``ttl``. The definition of “activity” depends on the
          type of the associated resource. The minimum and maximum
          allowed values for ``ttl`` depend on the type of the
          associated resource, as well. If ``ttl`` is not set, the
          associated resource never expires.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ExpirationPolicy)
    },
)
_sym_db.RegisterMessage(ExpirationPolicy)

PushConfig = _reflection.GeneratedProtocolMessageType(
    "PushConfig",
    (_message.Message,),
    {
        "OidcToken": _reflection.GeneratedProtocolMessageType(
            "OidcToken",
            (_message.Message,),
            {
                "DESCRIPTOR": _PUSHCONFIG_OIDCTOKEN,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
                "__doc__": """Contains information needed for generating an `OpenID Connect token
    <https://developers.google.com/identity/protocols/OpenIDConnect>`__.

    
    Attributes:
        service_account_email:
            \ `Service account email
            <https://cloud.google.com/iam/docs/service-accounts>`__ to be
            used for generating the OIDC token. The caller (for
            CreateSubscription, UpdateSubscription, and ModifyPushConfig
            RPCs) must have the iam.serviceAccounts.actAs permission for
            the service account.
        audience:
            Audience to be used when generating OIDC token. The audience
            claim identifies the recipients that the JWT is intended for.
            The audience value is a single case-sensitive string. Having
            multiple values (array) for the audience field is not
            supported. More info about the OIDC JWT token audience here:
            https://tools.ietf.org/html/rfc7519#section-4.1.3 Note: if not
            specified, the Push endpoint URL will be used.
    """,
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.PushConfig.OidcToken)
            },
        ),
        "AttributesEntry": _reflection.GeneratedProtocolMessageType(
            "AttributesEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _PUSHCONFIG_ATTRIBUTESENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.PushConfig.AttributesEntry)
            },
        ),
        "DESCRIPTOR": _PUSHCONFIG,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Configuration for a push delivery endpoint.

  
  Attributes:
      push_endpoint:
          A URL locating the endpoint to which messages should be
          pushed. For example, a Webhook endpoint might use
          ``https://example.com/push``.
      attributes:
          Endpoint configuration attributes that can be used to control
          different aspects of the message delivery.  The only currently
          supported attribute is ``x-goog-version``, which you can use
          to change the format of the pushed message. This attribute
          indicates the version of the data expected by the endpoint.
          This controls the shape of the pushed message (i.e., its
          fields and metadata).  If not present during the
          ``CreateSubscription`` call, it will default to the version of
          the Pub/Sub API used to make such call. If not present in a
          ``ModifyPushConfig`` call, its value will not be changed.
          ``GetSubscription`` calls will always return a valid version,
          even if the subscription was created without this attribute.
          The only supported values for the ``x-goog-version`` attribute
          are:  -  ``v1beta1``: uses the push format defined in the
          v1beta1 Pub/Sub API. -  ``v1`` or ``v1beta2``: uses the push
          format defined in the v1 Pub/Sub    API.  For example:  ..
          raw:: html     <pre><code>attributes { "x-goog-version": "v1"
          } </code></pre>
      authentication_method:
          An authentication method used by push endpoints to verify the
          source of push requests. This can be used with push endpoints
          that are private by default to allow requests only from the
          Cloud Pub/Sub system, for example. This field is optional and
          should be set only by users interested in authenticated push.
      oidc_token:
          If specified, Pub/Sub will generate and attach an OIDC JWT
          token as an ``Authorization`` header in the HTTP request for
          every pushed message.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PushConfig)
    },
)
_sym_db.RegisterMessage(PushConfig)
_sym_db.RegisterMessage(PushConfig.OidcToken)
_sym_db.RegisterMessage(PushConfig.AttributesEntry)

ReceivedMessage = _reflection.GeneratedProtocolMessageType(
    "ReceivedMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _RECEIVEDMESSAGE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A message and its corresponding acknowledgment ID.

  
  Attributes:
      ack_id:
          This ID can be used to acknowledge the received message.
      message:
          The message.
      delivery_attempt:
          The approximate number of times that Cloud Pub/Sub has
          attempted to deliver the associated message to a subscriber.
          More precisely, this is 1 + (number of NACKs) + (number of
          ack_deadline exceeds) for this message.  A NACK is any call to
          ModifyAckDeadline with a 0 deadline. An ack_deadline exceeds
          event is whenever a message is not acknowledged within
          ack_deadline. Note that ack_deadline is initially
          Subscription.ackDeadlineSeconds, but may get extended
          automatically by the client library.  Upon the first delivery
          of a given message, ``delivery_attempt`` will have a value of
          1. The value is calculated at best effort and is approximate.
          If a DeadLetterPolicy is not set on the subscription, this
          will be 0.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ReceivedMessage)
    },
)
_sym_db.RegisterMessage(ReceivedMessage)

GetSubscriptionRequest = _reflection.GeneratedProtocolMessageType(
    "GetSubscriptionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSUBSCRIPTIONREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the GetSubscription method.

  
  Attributes:
      subscription:
          Required. The name of the subscription to get. Format is
          ``projects/{project}/subscriptions/{sub}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.GetSubscriptionRequest)
    },
)
_sym_db.RegisterMessage(GetSubscriptionRequest)

UpdateSubscriptionRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateSubscriptionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATESUBSCRIPTIONREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the UpdateSubscription method.

  
  Attributes:
      subscription:
          Required. The updated subscription object.
      update_mask:
          Required. Indicates which fields in the provided subscription
          to update. Must be specified and non-empty.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.UpdateSubscriptionRequest)
    },
)
_sym_db.RegisterMessage(UpdateSubscriptionRequest)

ListSubscriptionsRequest = _reflection.GeneratedProtocolMessageType(
    "ListSubscriptionsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTSUBSCRIPTIONSREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``ListSubscriptions`` method.

  
  Attributes:
      project:
          Required. The name of the project in which to list
          subscriptions. Format is ``projects/{project-id}``.
      page_size:
          Maximum number of subscriptions to return.
      page_token:
          The value returned by the last ``ListSubscriptionsResponse``;
          indicates that this is a continuation of a prior
          ``ListSubscriptions`` call, and that the system should return
          the next page of data.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListSubscriptionsRequest)
    },
)
_sym_db.RegisterMessage(ListSubscriptionsRequest)

ListSubscriptionsResponse = _reflection.GeneratedProtocolMessageType(
    "ListSubscriptionsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTSUBSCRIPTIONSRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``ListSubscriptions`` method.

  
  Attributes:
      subscriptions:
          The subscriptions that match the request.
      next_page_token:
          If not empty, indicates that there may be more subscriptions
          that match the request; this value should be passed in a new
          ``ListSubscriptionsRequest`` to get more subscriptions.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListSubscriptionsResponse)
    },
)
_sym_db.RegisterMessage(ListSubscriptionsResponse)

DeleteSubscriptionRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteSubscriptionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETESUBSCRIPTIONREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the DeleteSubscription method.

  
  Attributes:
      subscription:
          Required. The subscription to delete. Format is
          ``projects/{project}/subscriptions/{sub}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DeleteSubscriptionRequest)
    },
)
_sym_db.RegisterMessage(DeleteSubscriptionRequest)

ModifyPushConfigRequest = _reflection.GeneratedProtocolMessageType(
    "ModifyPushConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MODIFYPUSHCONFIGREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ModifyPushConfig method.

  
  Attributes:
      subscription:
          Required. The name of the subscription. Format is
          ``projects/{project}/subscriptions/{sub}``.
      push_config:
          Required. The push configuration for future deliveries.  An
          empty ``pushConfig`` indicates that the Pub/Sub system should
          stop pushing messages from the given subscription and allow
          messages to be pulled and acknowledged - effectively pausing
          the subscription if ``Pull`` or ``StreamingPull`` is not
          called.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ModifyPushConfigRequest)
    },
)
_sym_db.RegisterMessage(ModifyPushConfigRequest)

PullRequest = _reflection.GeneratedProtocolMessageType(
    "PullRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PULLREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``Pull`` method.

  
  Attributes:
      subscription:
          Required. The subscription from which messages should be
          pulled. Format is ``projects/{project}/subscriptions/{sub}``.
      return_immediately:
          Optional. If this field set to true, the system will respond
          immediately even if it there are no messages available to
          return in the ``Pull`` response. Otherwise, the system may
          wait (for a bounded amount of time) until at least one message
          is available, rather than returning no messages. Warning:
          setting this field to ``true`` is discouraged because it
          adversely impacts the performance of ``Pull`` operations. We
          recommend that users do not set this field.
      max_messages:
          Required. The maximum number of messages to return for this
          request. Must be a positive integer. The Pub/Sub system may
          return fewer than the number specified.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PullRequest)
    },
)
_sym_db.RegisterMessage(PullRequest)

PullResponse = _reflection.GeneratedProtocolMessageType(
    "PullResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _PULLRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``Pull`` method.

  
  Attributes:
      received_messages:
          Received Pub/Sub messages. The list will be empty if there are
          no more messages available in the backlog. For JSON, the
          response can be entirely empty. The Pub/Sub system may return
          fewer than the ``maxMessages`` requested even if there are
          more messages available in the backlog.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.PullResponse)
    },
)
_sym_db.RegisterMessage(PullResponse)

ModifyAckDeadlineRequest = _reflection.GeneratedProtocolMessageType(
    "ModifyAckDeadlineRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _MODIFYACKDEADLINEREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ModifyAckDeadline method.

  
  Attributes:
      subscription:
          Required. The name of the subscription. Format is
          ``projects/{project}/subscriptions/{sub}``.
      ack_ids:
          Required. List of acknowledgment IDs.
      ack_deadline_seconds:
          Required. The new ack deadline with respect to the time this
          request was sent to the Pub/Sub system. For example, if the
          value is 10, the new ack deadline will expire 10 seconds after
          the ``ModifyAckDeadline`` call was made. Specifying zero might
          immediately make the message available for delivery to another
          subscriber client. This typically results in an increase in
          the rate of message redeliveries (that is, duplicates). The
          minimum deadline you can specify is 0 seconds. The maximum
          deadline you can specify is 600 seconds (10 minutes).
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ModifyAckDeadlineRequest)
    },
)
_sym_db.RegisterMessage(ModifyAckDeadlineRequest)

AcknowledgeRequest = _reflection.GeneratedProtocolMessageType(
    "AcknowledgeRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _ACKNOWLEDGEREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the Acknowledge method.

  
  Attributes:
      subscription:
          Required. The subscription whose message is being
          acknowledged. Format is
          ``projects/{project}/subscriptions/{sub}``.
      ack_ids:
          Required. The acknowledgment ID for the messages being
          acknowledged that was returned by the Pub/Sub system in the
          ``Pull`` response. Must not be empty.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.AcknowledgeRequest)
    },
)
_sym_db.RegisterMessage(AcknowledgeRequest)

StreamingPullRequest = _reflection.GeneratedProtocolMessageType(
    "StreamingPullRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGPULLREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``StreamingPull`` streaming RPC method. This request
  is used to establish the initial stream as well as to stream
  acknowledgements and ack deadline modifications from the client to the
  server.

  
  Attributes:
      subscription:
          Required. The subscription for which to initialize the new
          stream. This must be provided in the first request on the
          stream, and must not be set in subsequent requests from client
          to server. Format is
          ``projects/{project}/subscriptions/{sub}``.
      ack_ids:
          List of acknowledgement IDs for acknowledging previously
          received messages (received on this stream or a different
          stream). If an ack ID has expired, the corresponding message
          may be redelivered later. Acknowledging a message more than
          once will not result in an error. If the acknowledgement ID is
          malformed, the stream will be aborted with status
          ``INVALID_ARGUMENT``.
      modify_deadline_seconds:
          The list of new ack deadlines for the IDs listed in
          ``modify_deadline_ack_ids``. The size of this list must be the
          same as the size of ``modify_deadline_ack_ids``. If it differs
          the stream will be aborted with ``INVALID_ARGUMENT``. Each
          element in this list is applied to the element in the same
          position in ``modify_deadline_ack_ids``. The new ack deadline
          is with respect to the time this request was sent to the
          Pub/Sub system. Must be >= 0. For example, if the value is 10,
          the new ack deadline will expire 10 seconds after this request
          is received. If the value is 0, the message is immediately
          made available for another streaming or non-streaming pull
          request. If the value is < 0 (an error), the stream will be
          aborted with status ``INVALID_ARGUMENT``.
      modify_deadline_ack_ids:
          List of acknowledgement IDs whose deadline will be modified
          based on the corresponding element in
          ``modify_deadline_seconds``. This field can be used to
          indicate that more time is needed to process a message by the
          subscriber, or to make the message available for redelivery if
          the processing was interrupted.
      stream_ack_deadline_seconds:
          Required. The ack deadline to use for the stream. This must be
          provided in the first request on the stream, but it can also
          be updated on subsequent requests from client to server. The
          minimum deadline you can specify is 10 seconds. The maximum
          deadline you can specify is 600 seconds (10 minutes).
      client_id:
          A unique identifier that is used to distinguish client
          instances from each other. Only needs to be provided on the
          initial request. When a stream disconnects and reconnects for
          the same stream, the client_id should be set to the same value
          so that state associated with the old stream can be
          transferred to the new stream. The same client_id should not
          be used for different client instances.
      max_outstanding_messages:
          Flow control settings for the maximum number of outstanding
          messages. When there are ``max_outstanding_messages`` or more
          currently sent to the streaming pull client that have not yet
          been acked or nacked, the server stops sending more messages.
          The sending of messages resumes once the number of outstanding
          messages is less than this value. If the value is <= 0, there
          is no limit to the number of outstanding messages. This
          property can only be set on the initial StreamingPullRequest.
          If it is set on a subsequent request, the stream will be
          aborted with status ``INVALID_ARGUMENT``.
      max_outstanding_bytes:
          Flow control settings for the maximum number of outstanding
          bytes. When there are ``max_outstanding_bytes`` or more worth
          of messages currently sent to the streaming pull client that
          have not yet been acked or nacked, the server will stop
          sending more messages. The sending of messages resumes once
          the number of outstanding bytes is less than this value. If
          the value is <= 0, there is no limit to the number of
          outstanding bytes. This property can only be set on the
          initial StreamingPullRequest. If it is set on a subsequent
          request, the stream will be aborted with status
          ``INVALID_ARGUMENT``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.StreamingPullRequest)
    },
)
_sym_db.RegisterMessage(StreamingPullRequest)

StreamingPullResponse = _reflection.GeneratedProtocolMessageType(
    "StreamingPullResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGPULLRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``StreamingPull`` method. This response is used to
  stream messages from the server to the client.

  
  Attributes:
      received_messages:
          Received Pub/Sub messages. This will not be empty.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.StreamingPullResponse)
    },
)
_sym_db.RegisterMessage(StreamingPullResponse)

CreateSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "CreateSnapshotRequest",
    (_message.Message,),
    {
        "LabelsEntry": _reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _CREATESNAPSHOTREQUEST_LABELSENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.CreateSnapshotRequest.LabelsEntry)
            },
        ),
        "DESCRIPTOR": _CREATESNAPSHOTREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``CreateSnapshot`` method.

  
  Attributes:
      name:
          Required. User-provided name for this snapshot. If the name is
          not provided in the request, the server will assign a random
          name for this snapshot on the same project as the
          subscription. Note that for REST API requests, you must
          specify a name. See the resource name rules. Format is
          ``projects/{project}/snapshots/{snap}``.
      subscription:
          Required. The subscription whose backlog the snapshot retains.
          Specifically, the created snapshot is guaranteed to retain:
          (a) The existing backlog on the subscription. More precisely,
          this is defined as the messages in the subscription’s backlog
          that are unacknowledged upon the successful completion of the
          ``CreateSnapshot`` request; as well as: (b) Any messages
          published to the subscription’s topic following the successful
          completion of the CreateSnapshot request. Format is
          ``projects/{project}/subscriptions/{sub}``.
      labels:
          See Creating and managing labels.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.CreateSnapshotRequest)
    },
)
_sym_db.RegisterMessage(CreateSnapshotRequest)
_sym_db.RegisterMessage(CreateSnapshotRequest.LabelsEntry)

UpdateSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateSnapshotRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATESNAPSHOTREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the UpdateSnapshot method.

  
  Attributes:
      snapshot:
          Required. The updated snapshot object.
      update_mask:
          Required. Indicates which fields in the provided snapshot to
          update. Must be specified and non-empty.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.UpdateSnapshotRequest)
    },
)
_sym_db.RegisterMessage(UpdateSnapshotRequest)

Snapshot = _reflection.GeneratedProtocolMessageType(
    "Snapshot",
    (_message.Message,),
    {
        "LabelsEntry": _reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _SNAPSHOT_LABELSENTRY,
                "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2"
                # @@protoc_insertion_point(class_scope:google.pubsub.v1.Snapshot.LabelsEntry)
            },
        ),
        "DESCRIPTOR": _SNAPSHOT,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """A snapshot resource. Snapshots are used in Seek operations, which
  allow you to manage message acknowledgments in bulk. That is, you can
  set the acknowledgment state of messages in an existing subscription
  to the state captured by a snapshot.

  
  Attributes:
      name:
          The name of the snapshot.
      topic:
          The name of the topic from which this snapshot is retaining
          messages.
      expire_time:
          The snapshot is guaranteed to exist up until this time. A
          newly-created snapshot expires no later than 7 days from the
          time of its creation. Its exact lifetime is determined at
          creation by the existing backlog in the source subscription.
          Specifically, the lifetime of the snapshot is ``7 days - (age
          of oldest unacked message in the subscription)``. For example,
          consider a subscription whose oldest unacked message is 3 days
          old. If a snapshot is created from this subscription, the
          snapshot – which will always capture this 3-day-old backlog as
          long as the snapshot exists – will expire in 4 days. The
          service will refuse to create a snapshot that would expire in
          less than 1 hour after creation.
      labels:
          See Creating and managing labels.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.Snapshot)
    },
)
_sym_db.RegisterMessage(Snapshot)
_sym_db.RegisterMessage(Snapshot.LabelsEntry)

GetSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "GetSnapshotRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSNAPSHOTREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the GetSnapshot method.

  
  Attributes:
      snapshot:
          Required. The name of the snapshot to get. Format is
          ``projects/{project}/snapshots/{snap}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.GetSnapshotRequest)
    },
)
_sym_db.RegisterMessage(GetSnapshotRequest)

ListSnapshotsRequest = _reflection.GeneratedProtocolMessageType(
    "ListSnapshotsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTSNAPSHOTSREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``ListSnapshots`` method.

  
  Attributes:
      project:
          Required. The name of the project in which to list snapshots.
          Format is ``projects/{project-id}``.
      page_size:
          Maximum number of snapshots to return.
      page_token:
          The value returned by the last ``ListSnapshotsResponse``;
          indicates that this is a continuation of a prior
          ``ListSnapshots`` call, and that the system should return the
          next page of data.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListSnapshotsRequest)
    },
)
_sym_db.RegisterMessage(ListSnapshotsRequest)

ListSnapshotsResponse = _reflection.GeneratedProtocolMessageType(
    "ListSnapshotsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTSNAPSHOTSRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``ListSnapshots`` method.

  
  Attributes:
      snapshots:
          The resulting snapshots.
      next_page_token:
          If not empty, indicates that there may be more snapshot that
          match the request; this value should be passed in a new
          ``ListSnapshotsRequest``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.ListSnapshotsResponse)
    },
)
_sym_db.RegisterMessage(ListSnapshotsResponse)

DeleteSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteSnapshotRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETESNAPSHOTREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``DeleteSnapshot`` method.

  
  Attributes:
      snapshot:
          Required. The name of the snapshot to delete. Format is
          ``projects/{project}/snapshots/{snap}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.DeleteSnapshotRequest)
    },
)
_sym_db.RegisterMessage(DeleteSnapshotRequest)

SeekRequest = _reflection.GeneratedProtocolMessageType(
    "SeekRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEEKREQUEST,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Request for the ``Seek`` method.

  
  Attributes:
      subscription:
          Required. The subscription to affect.
      time:
          The time to seek to. Messages retained in the subscription
          that were published before this time are marked as
          acknowledged, and messages retained in the subscription that
          were published after this time are marked as unacknowledged.
          Note that this operation affects only those messages retained
          in the subscription (configured by the combination of
          ``message_retention_duration`` and ``retain_acked_messages``).
          For example, if ``time`` corresponds to a point before the
          message retention window (or to a point before the system’s
          notion of the subscription creation time), only retained
          messages will be marked as unacknowledged, and already-
          expunged messages will not be restored.
      snapshot:
          The snapshot to seek to. The snapshot’s topic must be the same
          as that of the provided subscription. Format is
          ``projects/{project}/snapshots/{snap}``.
  """,
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.SeekRequest)
    },
)
_sym_db.RegisterMessage(SeekRequest)

SeekResponse = _reflection.GeneratedProtocolMessageType(
    "SeekResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEEKRESPONSE,
        "__module__": "google.cloud.pubsub_v1.proto.pubsub_pb2",
        "__doc__": """Response for the ``Seek`` method (this response is empty).""",
        # @@protoc_insertion_point(class_scope:google.pubsub.v1.SeekResponse)
    },
)
_sym_db.RegisterMessage(SeekResponse)


DESCRIPTOR._options = None
_TOPIC_LABELSENTRY._options = None
_TOPIC.fields_by_name["name"]._options = None
_TOPIC._options = None
_PUBSUBMESSAGE_ATTRIBUTESENTRY._options = None
_GETTOPICREQUEST.fields_by_name["topic"]._options = None
_UPDATETOPICREQUEST.fields_by_name["topic"]._options = None
_UPDATETOPICREQUEST.fields_by_name["update_mask"]._options = None
_PUBLISHREQUEST.fields_by_name["topic"]._options = None
_PUBLISHREQUEST.fields_by_name["messages"]._options = None
_LISTTOPICSREQUEST.fields_by_name["project"]._options = None
_LISTTOPICSUBSCRIPTIONSREQUEST.fields_by_name["topic"]._options = None
_LISTTOPICSUBSCRIPTIONSRESPONSE.fields_by_name["subscriptions"]._options = None
_LISTTOPICSNAPSHOTSREQUEST.fields_by_name["topic"]._options = None
_DELETETOPICREQUEST.fields_by_name["topic"]._options = None
_DETACHSUBSCRIPTIONREQUEST.fields_by_name["subscription"]._options = None
_SUBSCRIPTION_LABELSENTRY._options = None
_SUBSCRIPTION.fields_by_name["name"]._options = None
_SUBSCRIPTION.fields_by_name["topic"]._options = None
_SUBSCRIPTION._options = None
_PUSHCONFIG_ATTRIBUTESENTRY._options = None
_GETSUBSCRIPTIONREQUEST.fields_by_name["subscription"]._options = None
_UPDATESUBSCRIPTIONREQUEST.fields_by_name["subscription"]._options = None
_UPDATESUBSCRIPTIONREQUEST.fields_by_name["update_mask"]._options = None
_LISTSUBSCRIPTIONSREQUEST.fields_by_name["project"]._options = None
_DELETESUBSCRIPTIONREQUEST.fields_by_name["subscription"]._options = None
_MODIFYPUSHCONFIGREQUEST.fields_by_name["subscription"]._options = None
_MODIFYPUSHCONFIGREQUEST.fields_by_name["push_config"]._options = None
_PULLREQUEST.fields_by_name["subscription"]._options = None
_PULLREQUEST.fields_by_name["return_immediately"]._options = None
_PULLREQUEST.fields_by_name["max_messages"]._options = None
_MODIFYACKDEADLINEREQUEST.fields_by_name["subscription"]._options = None
_MODIFYACKDEADLINEREQUEST.fields_by_name["ack_ids"]._options = None
_MODIFYACKDEADLINEREQUEST.fields_by_name["ack_deadline_seconds"]._options = None
_ACKNOWLEDGEREQUEST.fields_by_name["subscription"]._options = None
_ACKNOWLEDGEREQUEST.fields_by_name["ack_ids"]._options = None
_STREAMINGPULLREQUEST.fields_by_name["subscription"]._options = None
_STREAMINGPULLREQUEST.fields_by_name["stream_ack_deadline_seconds"]._options = None
_CREATESNAPSHOTREQUEST_LABELSENTRY._options = None
_CREATESNAPSHOTREQUEST.fields_by_name["name"]._options = None
_CREATESNAPSHOTREQUEST.fields_by_name["subscription"]._options = None
_UPDATESNAPSHOTREQUEST.fields_by_name["snapshot"]._options = None
_UPDATESNAPSHOTREQUEST.fields_by_name["update_mask"]._options = None
_SNAPSHOT_LABELSENTRY._options = None
_SNAPSHOT.fields_by_name["topic"]._options = None
_SNAPSHOT._options = None
_GETSNAPSHOTREQUEST.fields_by_name["snapshot"]._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name["project"]._options = None
_DELETESNAPSHOTREQUEST.fields_by_name["snapshot"]._options = None
_SEEKREQUEST.fields_by_name["subscription"]._options = None
_SEEKREQUEST.fields_by_name["snapshot"]._options = None

_PUBLISHER = _descriptor.ServiceDescriptor(
    name="Publisher",
    full_name="google.pubsub.v1.Publisher",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\025pubsub.googleapis.com\322AUhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/pubsub",
    create_key=_descriptor._internal_create_key,
    serialized_start=6417,
    serialized_end=7860,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateTopic",
            full_name="google.pubsub.v1.Publisher.CreateTopic",
            index=0,
            containing_service=None,
            input_type=_TOPIC,
            output_type=_TOPIC,
            serialized_options=b"\202\323\344\223\002#\032\036/v1/{name=projects/*/topics/*}:\001*\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTopic",
            full_name="google.pubsub.v1.Publisher.UpdateTopic",
            index=1,
            containing_service=None,
            input_type=_UPDATETOPICREQUEST,
            output_type=_TOPIC,
            serialized_options=b"\202\323\344\223\002)2$/v1/{topic.name=projects/*/topics/*}:\001*",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Publish",
            full_name="google.pubsub.v1.Publisher.Publish",
            index=2,
            containing_service=None,
            input_type=_PUBLISHREQUEST,
            output_type=_PUBLISHRESPONSE,
            serialized_options=b"\202\323\344\223\002,\"'/v1/{topic=projects/*/topics/*}:publish:\001*\332A\016topic,messages",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetTopic",
            full_name="google.pubsub.v1.Publisher.GetTopic",
            index=3,
            containing_service=None,
            input_type=_GETTOPICREQUEST,
            output_type=_TOPIC,
            serialized_options=b"\202\323\344\223\002!\022\037/v1/{topic=projects/*/topics/*}\332A\005topic",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTopics",
            full_name="google.pubsub.v1.Publisher.ListTopics",
            index=4,
            containing_service=None,
            input_type=_LISTTOPICSREQUEST,
            output_type=_LISTTOPICSRESPONSE,
            serialized_options=b"\202\323\344\223\002!\022\037/v1/{project=projects/*}/topics\332A\007project",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTopicSubscriptions",
            full_name="google.pubsub.v1.Publisher.ListTopicSubscriptions",
            index=5,
            containing_service=None,
            input_type=_LISTTOPICSUBSCRIPTIONSREQUEST,
            output_type=_LISTTOPICSUBSCRIPTIONSRESPONSE,
            serialized_options=b"\202\323\344\223\002/\022-/v1/{topic=projects/*/topics/*}/subscriptions\332A\005topic",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTopicSnapshots",
            full_name="google.pubsub.v1.Publisher.ListTopicSnapshots",
            index=6,
            containing_service=None,
            input_type=_LISTTOPICSNAPSHOTSREQUEST,
            output_type=_LISTTOPICSNAPSHOTSRESPONSE,
            serialized_options=b"\202\323\344\223\002+\022)/v1/{topic=projects/*/topics/*}/snapshots\332A\005topic",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTopic",
            full_name="google.pubsub.v1.Publisher.DeleteTopic",
            index=7,
            containing_service=None,
            input_type=_DELETETOPICREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002!*\037/v1/{topic=projects/*/topics/*}\332A\005topic",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DetachSubscription",
            full_name="google.pubsub.v1.Publisher.DetachSubscription",
            index=8,
            containing_service=None,
            input_type=_DETACHSUBSCRIPTIONREQUEST,
            output_type=_DETACHSUBSCRIPTIONRESPONSE,
            serialized_options=b'\202\323\344\223\0026"4/v1/{subscription=projects/*/subscriptions/*}:detach',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_PUBLISHER)

DESCRIPTOR.services_by_name["Publisher"] = _PUBLISHER


_SUBSCRIBER = _descriptor.ServiceDescriptor(
    name="Subscriber",
    full_name="google.pubsub.v1.Subscriber",
    file=DESCRIPTOR,
    index=1,
    serialized_options=b"\312A\025pubsub.googleapis.com\322AUhttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/pubsub",
    create_key=_descriptor._internal_create_key,
    serialized_start=7863,
    serialized_end=10554,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateSubscription",
            full_name="google.pubsub.v1.Subscriber.CreateSubscription",
            index=0,
            containing_service=None,
            input_type=_SUBSCRIPTION,
            output_type=_SUBSCRIPTION,
            serialized_options=b"\202\323\344\223\002*\032%/v1/{name=projects/*/subscriptions/*}:\001*\332A+name,topic,push_config,ack_deadline_seconds",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetSubscription",
            full_name="google.pubsub.v1.Subscriber.GetSubscription",
            index=1,
            containing_service=None,
            input_type=_GETSUBSCRIPTIONREQUEST,
            output_type=_SUBSCRIPTION,
            serialized_options=b"\202\323\344\223\002/\022-/v1/{subscription=projects/*/subscriptions/*}\332A\014subscription",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateSubscription",
            full_name="google.pubsub.v1.Subscriber.UpdateSubscription",
            index=2,
            containing_service=None,
            input_type=_UPDATESUBSCRIPTIONREQUEST,
            output_type=_SUBSCRIPTION,
            serialized_options=b"\202\323\344\223\002722/v1/{subscription.name=projects/*/subscriptions/*}:\001*",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListSubscriptions",
            full_name="google.pubsub.v1.Subscriber.ListSubscriptions",
            index=3,
            containing_service=None,
            input_type=_LISTSUBSCRIPTIONSREQUEST,
            output_type=_LISTSUBSCRIPTIONSRESPONSE,
            serialized_options=b"\202\323\344\223\002(\022&/v1/{project=projects/*}/subscriptions\332A\007project",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteSubscription",
            full_name="google.pubsub.v1.Subscriber.DeleteSubscription",
            index=4,
            containing_service=None,
            input_type=_DELETESUBSCRIPTIONREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002/*-/v1/{subscription=projects/*/subscriptions/*}\332A\014subscription",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ModifyAckDeadline",
            full_name="google.pubsub.v1.Subscriber.ModifyAckDeadline",
            index=5,
            containing_service=None,
            input_type=_MODIFYACKDEADLINEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b'\202\323\344\223\002D"?/v1/{subscription=projects/*/subscriptions/*}:modifyAckDeadline:\001*\332A)subscription,ack_ids,ack_deadline_seconds',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Acknowledge",
            full_name="google.pubsub.v1.Subscriber.Acknowledge",
            index=6,
            containing_service=None,
            input_type=_ACKNOWLEDGEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b'\202\323\344\223\002>"9/v1/{subscription=projects/*/subscriptions/*}:acknowledge:\001*\332A\024subscription,ack_ids',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Pull",
            full_name="google.pubsub.v1.Subscriber.Pull",
            index=7,
            containing_service=None,
            input_type=_PULLREQUEST,
            output_type=_PULLRESPONSE,
            serialized_options=b'\202\323\344\223\0027"2/v1/{subscription=projects/*/subscriptions/*}:pull:\001*\332A,subscription,return_immediately,max_messages',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StreamingPull",
            full_name="google.pubsub.v1.Subscriber.StreamingPull",
            index=8,
            containing_service=None,
            input_type=_STREAMINGPULLREQUEST,
            output_type=_STREAMINGPULLRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ModifyPushConfig",
            full_name="google.pubsub.v1.Subscriber.ModifyPushConfig",
            index=9,
            containing_service=None,
            input_type=_MODIFYPUSHCONFIGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b'\202\323\344\223\002C">/v1/{subscription=projects/*/subscriptions/*}:modifyPushConfig:\001*\332A\030subscription,push_config',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetSnapshot",
            full_name="google.pubsub.v1.Subscriber.GetSnapshot",
            index=10,
            containing_service=None,
            input_type=_GETSNAPSHOTREQUEST,
            output_type=_SNAPSHOT,
            serialized_options=b"\202\323\344\223\002'\022%/v1/{snapshot=projects/*/snapshots/*}\332A\010snapshot",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListSnapshots",
            full_name="google.pubsub.v1.Subscriber.ListSnapshots",
            index=11,
            containing_service=None,
            input_type=_LISTSNAPSHOTSREQUEST,
            output_type=_LISTSNAPSHOTSRESPONSE,
            serialized_options=b'\202\323\344\223\002$\022"/v1/{project=projects/*}/snapshots\332A\007project',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateSnapshot",
            full_name="google.pubsub.v1.Subscriber.CreateSnapshot",
            index=12,
            containing_service=None,
            input_type=_CREATESNAPSHOTREQUEST,
            output_type=_SNAPSHOT,
            serialized_options=b"\202\323\344\223\002&\032!/v1/{name=projects/*/snapshots/*}:\001*\332A\021name,subscription",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateSnapshot",
            full_name="google.pubsub.v1.Subscriber.UpdateSnapshot",
            index=13,
            containing_service=None,
            input_type=_UPDATESNAPSHOTREQUEST,
            output_type=_SNAPSHOT,
            serialized_options=b"\202\323\344\223\002/2*/v1/{snapshot.name=projects/*/snapshots/*}:\001*",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteSnapshot",
            full_name="google.pubsub.v1.Subscriber.DeleteSnapshot",
            index=14,
            containing_service=None,
            input_type=_DELETESNAPSHOTREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002'*%/v1/{snapshot=projects/*/snapshots/*}\332A\010snapshot",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Seek",
            full_name="google.pubsub.v1.Subscriber.Seek",
            index=15,
            containing_service=None,
            input_type=_SEEKREQUEST,
            output_type=_SEEKRESPONSE,
            serialized_options=b'\202\323\344\223\0027"2/v1/{subscription=projects/*/subscriptions/*}:seek:\001*',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_SUBSCRIBER)

DESCRIPTOR.services_by_name["Subscriber"] = _SUBSCRIBER

# @@protoc_insertion_point(module_scope)
